package Qt::Gui::QGraphicsScale;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QGraphicsScale
# file     : QtGui/qgraphicstransform.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QGraphicsTransform/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QGraphicsScale

=head1 PUBLIC METHODS

=over

=item   QGraphicsScale(QObject * parent)

=item   QGraphicsScale(QObject * parent = 0)

=item   ~QGraphicsScale()

=item  void applyTo(QMatrix4x4 * matrix)

=item  QVector3D origin()

=item  void setOrigin(const QVector3D & point)

=item  void setXScale(qreal arg0)

=item  void setYScale(qreal arg0)

=item  void setZScale(qreal arg0)

=item  qreal xScale()

=item  qreal yScale()

=item  qreal zScale()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
